@@ -2,7 +2,7 @@ import subprocess
 import datetime
 import os
 
-VERSION = __version__ = (0, 7, 1, 'final', 0)
+VERSION = __version__ = (0, 8, 0, 'final', 0)
 __author__ = 'sax'
 
 
@@ -41,7 +41,8 @@ so it's sufficient for generating the development version numbers.
     repo_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
     git_log = subprocess.Popen('git log --pretty=format:%ct --quiet -1 HEAD',
                                stdout=subprocess.PIPE, stderr=subprocess.PIPE,
-                               shell=True, cwd=repo_dir, universal_newlines=True)
+                               shell=True, cwd=repo_dir,
+                               universal_newlines=True)
     timestamp = git_log.communicate()[0]
     try:
         timestamp = datetime.datetime.utcfromtimestamp(int(timestamp))
