@@ -77,11 +77,13 @@ def apply_concurrency_check(model, fieldname, versionclass):
     :type versionclass: concurrency.fields.VersionField subclass
     """
     if hasattr(model, '_concurrencymeta'):
-        raise ImproperlyConfigured("%s is already under concurrency management" % model)
+        return
+        # raise ImproperlyConfigured("%s is already under concurrency management" % model)
 
     logger.debug('Applying concurrency check to %s' % model)
 
     ver = versionclass()
+    # import ipdb; ipdb.set_trace()
     ver.contribute_to_class(model, fieldname)
     model._concurrencymeta._field = ver
 
