@@ -1,17 +1,15 @@
 from __future__ import absolute_import, unicode_literals
 import django
 from django import forms
-from django.core import validators
 from django.core.exceptions import NON_FIELD_ERRORS, ImproperlyConfigured, ValidationError
 from django.core.signing import Signer, BadSignature
 from django.forms import ModelForm, HiddenInput
-from django.utils import timezone
 from django.utils.importlib import import_module
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext as _
 from concurrency.config import conf
-from concurrency.core import _select_lock, RecordModifiedError
-from concurrency.exceptions import VersionError
+from concurrency.core import _select_lock
+from concurrency.exceptions import VersionError, RecordModifiedError
 
 
 class ConcurrentForm(ModelForm):
@@ -23,12 +21,14 @@ class ConcurrentForm(ModelForm):
 
     def clean(self):
         try:
-            _select_lock(self.instance, self.cleaned_data[self.instance.RevisionMetaInfo.field.name])
+            if self.instance.pk:
+                _select_lock(self.instance, self.cleaned_data[self.instance._concurrencymeta._field.name])
+
         except RecordModifiedError:
-            if django.VERSION[1] >= 6:
-                self._update_errors(ValidationError({NON_FIELD_ERRORS: self.error_class([_('Record Modified')])}))
-            else:
+            if django.VERSION[1] < 6:
                 self._update_errors({NON_FIELD_ERRORS: self.error_class([_('Record Modified')])})
+            else:
+                self._update_errors(ValidationError({NON_FIELD_ERRORS: self.error_class([_('Record Modified')])}))
 
         return super(ConcurrentForm, self).clean()
 
