@@ -3,7 +3,7 @@ from __future__ import absolute_import, unicode_literals
 from django.core.signals import got_request_exception
 from django.core.urlresolvers import get_callable
 from concurrency.config import conf
-from concurrency.core import RecordModifiedError
+from concurrency.exceptions import RecordModifiedError
 
 
 class ConcurrencyMiddleware(object):
