@@ -14,7 +14,8 @@ def identity(obj):
     returns a string representing "<pk>,<version>" of the passed object
     """
     if hasattr(obj, '_concurrencymeta'):
-        return mark_safe("{0},{1}".format(unlocalize(obj.pk), get_revision_of_object(obj)))
+        return mark_safe("{0},{1}".format(unlocalize(obj.pk),
+                                          get_revision_of_object(obj)))
     else:
         return mark_safe(unlocalize(obj.pk))
 
